==> haskell-xss-sanitize-0.3.5.6-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-xss-sanitize/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xss-sanitize
version: 0.3.5.6
id: xss-sanitize-0.3.5.6-230d5bf7daf3200c6f0f5ce353de0f41
key: xsssa_Ieljfuotpj40SUn8ffyj1C
license: BSD3
maintainer: Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://github.com/yesodweb/haskell-xss-sanitize
synopsis: sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details
category: Web
author: Greg Weber <greg@gregweber.info>
exposed: True
exposed-modules:
    Text.HTML.SanitizeXSS
hidden-modules: Text.HTML.SanitizeXSS.Css
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/xss-sanitize-0.3.5.6
library-dirs: /usr/lib/ghc-7.10.3/site-local/xss-sanitize-0.3.5.6
data-dir: /usr/share/arm-linux-ghc-7.10.3/xss-sanitize-0.3.5.6
hs-libraries: HSxss-sanitize-0.3.5.6-Ieljfuotpj40SUn8ffyj1C
depends:
    attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    css-text-0.1.2.1-9e91a6e24ab9d04d01b694bbf376f115
    network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
    tagsoup-0.13.8-ae67a6a9bc7b71798dd8f975b70085f0
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
haddock-interfaces: /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock
haddock-html: /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xss-sanitize-0.3.5.6-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-xss-sanitize/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xss-sanitize
version: 0.3.5.6
id: xss-sanitize-0.3.5.6-b3b679ace14b1ead6abf3b67e5cfe55e
key: xsssa_7U2g5IFmGbeEjvDVljaKqM
license: BSD3
maintainer: Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://github.com/yesodweb/haskell-xss-sanitize
synopsis: sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details
category: Web
author: Greg Weber <greg@gregweber.info>
exposed: True
exposed-modules:
    Text.HTML.SanitizeXSS
hidden-modules: Text.HTML.SanitizeXSS.Css
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/xss-sanitize-0.3.5.6
library-dirs: /usr/lib/ghc-7.10.3/site-local/xss-sanitize-0.3.5.6
data-dir: /usr/share/arm-linux-ghc-7.10.3/xss-sanitize-0.3.5.6
hs-libraries: HSxss-sanitize-0.3.5.6-7U2g5IFmGbeEjvDVljaKqM
depends:
    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    css-text-0.1.2.1-d1e175085ae55e4b9482a244b4d6aeb3
    network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
    tagsoup-0.13.8-ae67a6a9bc7b71798dd8f975b70085f0
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
haddock-interfaces: /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock
haddock-html: /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
